@@ -3,6 +3,6 @@
 
 #include "ptypes.h"
 
-extern int _XS_is_aks_prime(UV n);
+extern int is_aks_prime(UV n);
 
 #endif
